import tatsu.wrapper
import tatsu.data_structures
import tatsu.error

wrapper = tatsu.wrapper
data_structures = tatsu.data_structures
error = tatsu.error

__all__ = [
    'wrapper',
]

name = "tatsu.py"
version = "1.0.2"
